#------------------------------------------------------------------------------------------#
# FILE: Paper1.Analysis.Experiment1.R                                                      #  
#------------------------------------------------------------------------------------------#   

# Clear the R environment:
rm(list=ls(all=TRUE))

# Load the RJAGS library:
library(rjags)

# Set the working directory to root folder of our analysis:  
setwd("[path-to-files]")

# Load the data for the first experiment (data are stored in an R-binary)
load("Experiment1.R.data")
 
# Load the JAGS models: 
source("models/Paper1.Experiment1.Model0.R") 
source("models/Paper1.Experiment1.Model1.R")  
source("models/Paper1.Experiment1.Model2.R")
source("models/Paper1.Experiment1.Model3.R")
 
#Load models into a list:
MODELS      <- list()
MODELS[[1]] <- Paper1.Experiment1.Model0()
MODELS[[2]] <- Paper1.Experiment1.Model1()
MODELS[[3]] <- Paper1.Experiment1.Model2()
MODELS[[4]] <- Paper1.Experiment1.Model3()

# Combine payoffs into a matrix: 
P <- cbind(Experiment1$X1, Experiment1$X2,  Experiment1$X3,  Experiment1$X4,
           Experiment1$Y1, Experiment1$Y2,  Experiment1$Y3,  Experiment1$Y4)

# Scale payoffs to  estimation purposes:
P   <-   P / 25

#----------------------------------------------------#
#   P[,1] -> Payoffs for self under option 1         #
#   P[,2] -> Payoffs for receiver 1 under option 1   #
#   P[,3] -> Payoffs for receiver 2 under option 1   #
#   P[,4] -> Payoffs for receiver 3 under option 1   #
#                                                    #
#   P[,5] -> Payoffs for self under option 2         #
#   P[,6] -> Payoffs for receiver 1 under option 2   #
#   P[,7] -> Payoffs for receiver 2 under option 2   #
#   P[,8] -> Payoffs for receiver 3 under option 2   #
#----------------------------------------------------#

# Create a vector containing the difference in selfish payoffs:
dS  <-   P[,1] - P[,5]

# Create a vector containing the difference in social welfare
dW  <-   (P[,2]                           - P[,6])                        * (Experiment1$GameID < 11) + 
       (((P[,2] + P[,3] + P[,4])          - (P[,6] + P[,7] + P[,8]))/3)   * (Experiment1$GameID > 10)

# Create a vector containing the difference in self-centered inequality: 
dIs <-   (abs(P[,1] - P[,2])              - (abs(P[,5] - P[,6])))         * (Experiment1$GameID < 11) +
        ((abs(P[,1] - P[,2]) + abs(P[,1]  - P[,3])+abs(P[,1] - P[,4])) -                
         (abs(P[,5] - P[,6]) + abs(P[,5]  - P[,7])+abs(P[,5] - P[,8])))/3 * (Experiment1$GameID > 10)

# Create a vector containing the difference in non-self-centered inequality: 
dIns <- ((abs(P[,2] - P[,3]) + abs(P[,2]  - P[,4])+abs(P[,3] - P[,4])) -  
         (abs(P[,6] - P[,7]) + abs(P[,6]  - P[,8])+abs(P[,7] - P[,8])))/3 * (Experiment1$GameID > 10)

# Combine the data for JAGS in a named list object:  
DATA <- list(
    dS          = dS,
    dW          = dW,
    dIs         = dIs,
    dIns        = dIns,
    nObs        = 2960,
    nSubjects   = 148,
    denominator = rep(148,21),
    GameID      = Experiment1$GameID,
    Y           = Experiment1$CHOICE == 1, 
    SID         = Experiment1$Subject
)

# Initialize lists to store results: 
FIT     <- list()
SAMPLES <- list()
DIC     <- list()

# Define properties of the estimation procedure: 
iterations <- 50000
thin       <- 5

# Iterate over our vector of models: 
for(i in 1:length(MODELS)){ 
    paste0("Model ", i)
    
    # Fit the JAGS model
    FIT[[i]] <- jags.model(MODELS[[i]], data=DATA, n.chains=2, n.adapt=iterations)

    # Update the model
    update(FIT[[i]], iterations)
    
    # Draw samples
    SAMPLES[[i]] <- coda.samples(FIT[[i]],variable.names=c("mon","item","part1","part2"),n.iter=iterations, thin=thin)
    
    # Draw samples for the DIC
    DIC[[i]] <- dic.samples(FIT[[i]],iterations, thin=thin)
}

# Compare DIC of all models. 
DDIC <- list()

for(i in 1:4){     
    DDIC[[i]] <-list()
    
    for(j in 1:4){
        DDIC[[i]][[j]]<- diffdic(DIC[[i]],DIC[[j]])   
    }
}

# Save output files: 
save(SAMPLES, file="Experiment1.Output.SAMPLES")
save(DIC,     file="Experiment1.Output.DIC")
save(DDIC,    file="Experiment1.Output.DDIC")

