// Initialize Stata
version 13.1
clear all
set more off
cd "[path to data files]"

use Experiment1-Data.dta, replace

// Make a dummy to indicate that the game analyzed is a multiplayer variant
global isMultiplayer ((X3 > 0) & (X4 > 0) & (Y3 > 0) & (Y4 > 0))

// Generate term for difference in selfish payoffs
gen dS      =  X1 - Y1

// Generate term for difference in social welfare
gen dW      = (X2 + X3 + X4)/3 - (Y2 + Y3 + Y4)/3 if $isMultiplayer
replace dW  =  X2 - Y2 if ! $isMultiplayer

// Generate term for difference in self-centered inequality
gen dIs      = (abs(X2-X1)+abs(X3-X1)+abs(X4-X1))/3  - (abs(Y2-Y1)+abs(Y3-Y1)+abs(Y4-Y1))/3 if $isMultiplayer
replace dIs  =  abs(X2-X1) - abs(Y2-Y1) if ! $isMultiplayer

// Generate term for difference in non-self-centered inequality
gen dIns     = (abs(X2-X3)+abs(X2-X4)+abs(X3-X4))/3  - (abs(Y2-Y3)+abs(Y2-Y4)+abs(Y3-Y4))/3 if $isMultiplayer
replace dIns = 0 if ! $isMultiplayer

// Recode the 1 / 2 choice data to 0 / 1. 
gen ch = CHOICE == 1

// Note: in the data for Experiment 1, the CHOICE variable was coded as
//				 1 = option X is chosen (the left option on screen),
//				 2 = option Y is chosen (the right option on screen. )

// Note 2: the newly created ch variable is coded as: 
//				 1 = option X is chosen (the left option on screen),
//				 0 = option Y is chosen (the right option on screen. )


// Scale variables to ease estimation 
replace dS   = dS   / 25
replace dW   = dW   / 25
replace dIs  = dIs  / 25
replace dIns = dIns / 25

// Experiment 1 - Main model with three parameters. 

	//   Relevant options: 
	//    	(-) 	",nocons"  is needed to suppress the intercept; our model does not include one. 
	//    	(-) 	"family(binomial) link(probit)" makes the gsem-model an unscaled probit model. 
	//      (-)     "latent(L1 L2 L3)" is needed to tell gsem explicitly which variables are to be treated as latent. 
	
	//   Relevant defaults: 
	//      (-)     gsem per default estimates variances and covariances of and between latent parameters. 
    //              no restrictions are placed on these parameters, other than that the covariance matrix needs to be positive. 

	
gsem (ch <- dS c.dW     c.dW#L1[Subject] /// 
               c.dIs   c.dIs#L2[Subject] ///
			   c.dIns c.dIns#L3[Subject], nocons family(binomial) link(probit)), latent(L1 L2 L3)

// Store the model			   
est sto E1M3_full 

// Replay the model to see how Stata's gsem command names the coefficients
est replay E1M3_full, coeflegend

// Transform gsem's parameters to the desired scale, and report this in a table. 
nlcom (  _b[ch:dW]   / _b[ch:dS]  		                                                                         ) ///
      (  _b[ch:dIs]  / _b[ch:dS]                                                                                 ) ///
      (  _b[ch:dIns] / _b[ch:dS] 	                                                                             ) ///
	  (   sqrt(_b[var(L1[Subject]):_cons])/_b[ch:dS]                                                             ) ///
	  (   sqrt(_b[var(L2[Subject]):_cons])/_b[ch:dS]                                                             ) ///
	  (   sqrt(_b[var(L3[Subject]):_cons])/_b[ch:dS]  	                                                         ) ///
      ( (_b[cov(L1[Subject],L2[Subject]):_cons])/(sqrt(_b[var(L1[Subject]):_cons] * _b[var(L2[Subject]):_cons])) ) ///
      ( (_b[cov(L1[Subject],L3[Subject]):_cons])/(sqrt(_b[var(L1[Subject]):_cons] * _b[var(L3[Subject]):_cons])) ) ///
      ( (_b[cov(L2[Subject],L3[Subject]):_cons])/(sqrt(_b[var(L2[Subject]):_cons] * _b[var(L3[Subject]):_cons])) ) ///
	  ( 1 / _b[ch:dS]  ) 
